pub fn apply_container_proxy_opts_for_transport(
config: &mut ImageProxyConfig,
transport: Transport,
) -> Result<()>Expand description
Apply appropriate container proxy options based on transport type
pub fn apply_container_proxy_opts_for_transport(
config: &mut ImageProxyConfig,
transport: Transport,
) -> Result<()>Apply appropriate container proxy options based on transport type